from setuptools import setup, find_packages

setup(
    
    name='harilib',
    version='0.1.0',
    packages=find_packages(),
    author='Your Name',
    author_email='your_email@example.com',
    description='Format numbers in Indian format like 12,34,567',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/yourusername/harilib',  # optional GitHub link
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
